@@ -42,9 +42,9 @@ $^V eq v5.8.3
 #
 ## Package name      : perl5
 ## Source directory  : .
-## Configuration time: Fri Aug 24 16:31:33 EEST 2007
+## Configuration time: Thu Mar 13 13:53:13 EET 2008
 ## Configured by     : Debian Project
-## Target system     : linux titano 2.6.18-4-686-bigmem #1 smp thu may 10 00:23:00 utc 2007 arm gnulinux 
+## Target system     : linux doree 2.6.18-5-686-bigmem #1 smp wed oct 3 01:22:56 utc 2007 arm gnulinux 
 #
 ## Configure command line arguments.
 #PERL_PATCHLEVEL=
@@ -94,8 +94,8 @@ our $Config_SH : unique = <<'!END!';
 archlibexp='/usr/lib/perl/5.8'
 archname='arm-linux-gnueabi-thread-multi'
 cc='cc'
-ccflags='-D_REENTRANT -D_GNU_SOURCE -DTHREADS_HAVE_PIDS -DDEBIAN -march=armv3 -fno-strict-aliasing -I/usr/local/include -D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64'
-cppflags='-D_REENTRANT -D_GNU_SOURCE -DTHREADS_HAVE_PIDS -DDEBIAN -march=armv3 -fno-strict-aliasing -I/usr/local/include'
+ccflags='-D_REENTRANT -D_GNU_SOURCE -DTHREADS_HAVE_PIDS -DDEBIAN -fno-strict-aliasing -I/usr/local/include -D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64'
+cppflags='-D_REENTRANT -D_GNU_SOURCE -DTHREADS_HAVE_PIDS -DDEBIAN -fno-strict-aliasing -I/usr/local/include'
 dlsrc='dl_dlopen.xs'
 dynamic_ext='B ByteLoader Cwd Data/Dumper Devel/DProf Devel/PPPort Devel/Peek Digest/MD5 Encode Fcntl File/Glob Filter/Util/Call GDBM_File I18N/Langinfo IO IPC/SysV List/Util MIME/Base64 NDBM_File ODBM_File Opcode POSIX PerlIO/encoding PerlIO/scalar PerlIO/via SDBM_File Socket Storable Sys/Hostname Sys/Syslog Time/HiRes Unicode/Normalize XS/APItest XS/Typemap attrs re threads threads/shared'
 installarchlib='/usr/lib/perl/5.8'
@@ -103,7 +103,7 @@ installprivlib='/usr/share/perl/5.8'
 libpth='/usr/local/lib /lib /usr/lib'
 libs='-lgdbm -lgdbm_compat -ldl -lm -lpthread -lc -lcrypt'
 osname='linux'
-osvers='2.6.18-4-686-bigmem'
+osvers='2.6.18-5-686-bigmem'
 prefix='/usr'
 privlibexp='/usr/share/perl/5.8'
 sharpbang='#!'
@@ -168,7 +168,7 @@ ccsymbols=''
 ccversion=''
 cf_by='Debian Project'
 cf_email='perl@packages.debian.org'
-cf_time='Fri Aug 24 16:31:33 EEST 2007'
+cf_time='Thu Mar 13 13:53:13 EET 2008'
 charsize='1'
 chgrp=''
 chmod='chmod'
@@ -201,7 +201,7 @@ config_arg29='-Dlibperl=libperl.so.5.8.3'
 config_arg2='-Duselargefiles'
 config_arg30='-Dd_dosuid'
 config_arg31='-des'
-config_arg3='-Dccflags=-DDEBIAN -march=armv3'
+config_arg3='-Dccflags=-DDEBIAN'
 config_arg4='-Dcccdlflags=-fPIC'
 config_arg5='-Darchname=arm-linux-gnueabi'
 config_arg6='-Dprefix=/usr'
@@ -209,7 +209,7 @@ config_arg7='-Dprivlib=/usr/share/perl/5.8'
 config_arg8='-Darchlib=/usr/lib/perl/5.8'
 config_arg9='-Dvendorprefix=/usr'
 config_argc='31'
-config_args='-Dusethreads -Duselargefiles -Dccflags=-DDEBIAN -march=armv3 -Dcccdlflags=-fPIC -Darchname=arm-linux-gnueabi -Dprefix=/usr -Dprivlib=/usr/share/perl/5.8 -Darchlib=/usr/lib/perl/5.8 -Dvendorprefix=/usr -Dvendorlib=/usr/share/perl5 -Dvendorarch=/usr/lib/perl5 -Dsiteprefix=/usr/local -Dsitelib=/usr/local/share/perl/5.8.3 -Dsitearch=/usr/local/lib/perl/5.8.3 -Dman1dir=/usr/share/man/man1 -Dman3dir=/usr/share/man/man3 -Dsiteman1dir=/usr/local/man/man1 -Dsiteman3dir=/usr/local/man/man3 -Dman1ext=1 -Dman3ext=3perl -Dpager=/usr/bin/sensible-pager -A undef:i_db -Uafs -Ud_csh -Uusesfio -Uusenm -Duseshrplib -Dlibperl=libperl.so.5.8.3 -Dd_dosuid -des'
+config_args='-Dusethreads -Duselargefiles -Dccflags=-DDEBIAN -Dcccdlflags=-fPIC -Darchname=arm-linux-gnueabi -Dprefix=/usr -Dprivlib=/usr/share/perl/5.8 -Darchlib=/usr/lib/perl/5.8 -Dvendorprefix=/usr -Dvendorlib=/usr/share/perl5 -Dvendorarch=/usr/lib/perl5 -Dsiteprefix=/usr/local -Dsitelib=/usr/local/share/perl/5.8.3 -Dsitearch=/usr/local/lib/perl/5.8.3 -Dman1dir=/usr/share/man/man1 -Dman3dir=/usr/share/man/man3 -Dsiteman1dir=/usr/local/man/man1 -Dsiteman3dir=/usr/local/man/man3 -Dman1ext=1 -Dman3ext=3perl -Dpager=/usr/bin/sensible-pager -A undef:i_db -Uafs -Ud_csh -Uusesfio -Uusenm -Duseshrplib -Dlibperl=libperl.so.5.8.3 -Dd_dosuid -des'
 contains='grep'
 cp='cp'
 cpio=''
@@ -249,7 +249,7 @@ d_archlib='define'
 d_asctime_r='define'
 d_atolf='undef'
 d_atoll='define'
-d_attribut='undef'
+d_attribut='define'
 d_bcmp='define'
 d_bcopy='define'
 d_bsd='undef'
@@ -704,7 +704,7 @@ gzip='gzip'
 h_fcntl='false'
 h_sysfile='true'
 hint='recommended'
-hostcat='cat /etc/hosts'
+hostcat=''
 html1dir=' '
 html1direxp=''
 html3dir=' '
@@ -892,7 +892,7 @@ mv=''
 myarchname='arm-linux'
 mydomain=''
 myhostname='localhost'
-myuname='linux titano 2.6.18-4-686-bigmem #1 smp thu may 10 00:23:00 utc 2007 arm gnulinux '
+myuname='linux doree 2.6.18-5-686-bigmem #1 smp wed oct 3 01:22:56 utc 2007 arm gnulinux '
 n='-n'
 need_va_copy='undef'
 netdb_hlen_type='size_t'
@@ -1298,8 +1298,8 @@ tie %Config, 'Config', {
     'archlibexp' => '/usr/lib/perl/5.8',
     'archname' => 'arm-linux-gnueabi-thread-multi',
     'cc' => 'cc',
-    'ccflags' => '-D_REENTRANT -D_GNU_SOURCE -DTHREADS_HAVE_PIDS -DDEBIAN -march=armv3 -fno-strict-aliasing -I/usr/local/include -D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64',
-    'cppflags' => '-D_REENTRANT -D_GNU_SOURCE -DTHREADS_HAVE_PIDS -DDEBIAN -march=armv3 -fno-strict-aliasing -I/usr/local/include',
+    'ccflags' => '-D_REENTRANT -D_GNU_SOURCE -DTHREADS_HAVE_PIDS -DDEBIAN -fno-strict-aliasing -I/usr/local/include -D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64',
+    'cppflags' => '-D_REENTRANT -D_GNU_SOURCE -DTHREADS_HAVE_PIDS -DDEBIAN -fno-strict-aliasing -I/usr/local/include',
     'dlsrc' => 'dl_dlopen.xs',
     'dynamic_ext' => 'B ByteLoader Cwd Data/Dumper Devel/DProf Devel/PPPort Devel/Peek Digest/MD5 Encode Fcntl File/Glob Filter/Util/Call GDBM_File I18N/Langinfo IO IPC/SysV List/Util MIME/Base64 NDBM_File ODBM_File Opcode POSIX PerlIO/encoding PerlIO/scalar PerlIO/via SDBM_File Socket Storable Sys/Hostname Sys/Syslog Time/HiRes Unicode/Normalize XS/APItest XS/Typemap attrs re threads threads/shared',
     'installarchlib' => '/usr/lib/perl/5.8',
@@ -1307,7 +1307,7 @@ tie %Config, 'Config', {
     'libpth' => '/usr/local/lib /lib /usr/lib',
     'libs' => '-lgdbm -lgdbm_compat -ldl -lm -lpthread -lc -lcrypt',
     'osname' => 'linux',
-    'osvers' => '2.6.18-4-686-bigmem',
+    'osvers' => '2.6.18-5-686-bigmem',
     'prefix' => '/usr',
     'privlibexp' => '/usr/share/perl/5.8',
     'sharpbang' => '#!',
